@@ -1,6 +1,6 @@
 /**
  * JOnAS: Java(TM) Open Application Server
- * Copyright (C) 1999-2009 Bull S.A.S.
+ * Copyright (C) 1999-2011 Bull S.A.S.
  * Contact: jonas-team@ow2.org
  *
  * This library is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: ConnectionManagerImpl.java 21171 2011-04-18 16:12:53Z benoitf $
+ * $Id: ConnectionManagerImpl.java 21826 2011-10-21 11:54:42Z benoitf $
  * --------------------------------------------------------------------------
  */
 
@@ -725,7 +725,20 @@ public class ConnectionManagerImpl implements ConnectionEventListener, Connectio
                                         + mci.getXAResource() + " in Tx:"
                                         + currentTx);
                             }
-                            currentTx.enlistResource(mci.getXAResource());
+                            try {
+                                currentTx.enlistResource(mci.getXAResource());
+                            } catch (Exception e) {
+                                if (isEnabledDebug) {
+                                    trace.log(BasicLevel.DEBUG, "Could not enlist the XA Resource "
+                                            + mci.getXAResource() + " in Tx:"
+                                            + currentTx, e);
+                                }
+                                // Not able to enlist this connection, so delete it as it may have been closed by the remote side.
+                                retries++;
+                                connectionErrorOccurred(new ConnectionEvent(mci.mc,
+                                        ConnectionEvent.CONNECTION_ERROR_OCCURRED));
+                                continue;
+                            }
                             usedMCs.put(currentTx, mci);
                             mci.setGlobalTx(currentTx);
                         } else {
